'use strict';

var signalsReact = require('@preact/signals-react');

function get(object, path, index = 0) {
  const key = path[index];
  if (key === void 0)
    return "";
  const res = object[key];
  if (res === void 0)
    return "";
  if (typeof res === "string")
    return res;
  if (typeof res === "object" && res !== null) {
    return get(Object(res), path, index + 1);
  }
  throw new Error(`Unexpected value ${res} at ${key}`);
}
function replace(str, obj) {
  return str.replace(/{(.*?)}/g, (_, key) => obj[key]);
}

function createInstance(locales, initialLanguage) {
  const language = signalsReact.signal(initialLanguage);
  const dictionary = signalsReact.computed(() => locales[language.value]);
  const avaliableLanguages = signalsReact.computed(() => Object.keys(locales));
  const setLanguage = (_language) => {
    language.value = _language;
  };
  function t(key, replaceStrings) {
    if (!dictionary)
      return "";
    const value = get(
      dictionary.value,
      key.split(".")
    );
    if (replaceStrings)
      return replace(value, replaceStrings);
    return value;
  }
  return {
    t,
    language: language.value,
    avaliableLanguages: avaliableLanguages.value,
    setLanguage
  };
}

exports.createInstance = createInstance;
//# sourceMappingURL=index.cjs.map
